@@ -16,7 +16,7 @@
 #' @family spatial
 #' @family lookup
 #'
-#' @examples
+#' @examplesIf nominatim_check_access()
 #' \donttest{
 #' # Notre Dame Cathedral, Paris
 #'
@@ -93,7 +93,7 @@ geo_address_lookup_sf <- function(osm_ids,
   )
 
   if (is.null(res)) {
-    message(url, " not reachable.", nodes, call. = FALSE)
+    message(url, " not reachable.", nodes)
     result_out <- data.frame(query = paste0(type, osm_ids))
     return(result_out)
   }
@@ -107,7 +107,7 @@ geo_address_lookup_sf <- function(osm_ids,
   # Check if null and return
 
   if (length(names(sfobj)) == 1) {
-    message("No results for query ", nodes, call. = FALSE)
+    message("No results for query ", nodes)
     result_out <- data.frame(query = paste0(type, osm_ids))
     return(result_out)
   }
